@@ -1,4 +1,4 @@
-#%% begin initialize drupal-6.15-noarch-P1
+#%% begin initialize drupal-6.17-noarch-P1
 ###################################################################
 export LANG=C
 export PATH=/bin:/usr/bin:/sbin:/usr/sbin
@@ -20,24 +20,24 @@ fi
 if [ -f $ROOT/opt/htdocs/drupal6.bak/sites/default/settings.php ]; then
     # update for minor release(security fix and so on)
     /bin/cp -p $ROOT/opt/htdocs/drupal6.bak/sites/default/settings.php \
-	       $ROOT/opt/htdocs/drupal-6.15/sites/default/settings.php
+	       $ROOT/opt/htdocs/drupal-6.17/sites/default/settings.php
     (cd $ROOT/opt/htdocs/drupal6.bak/;
 	for i in `find sites/all/themes/ -mindepth 1 -maxdepth 1 -type d`; do \
-	    if [ ! -d $ROOT/opt/htdocs/drupal-6.15/$i ]; then
+	    if [ ! -d $ROOT/opt/htdocs/drupal-6.17/$i ]; then
 		echo "copying $i ..."
-		/bin/cp -a $i $ROOT/opt/htdocs/drupal-6.15/$i
+		/bin/cp -a $i $ROOT/opt/htdocs/drupal-6.17/$i
 	    fi
 	done
 	for i in `find sites/all/modules/ -mindepth 1 -maxdepth 1 -type d`; do \
-	    if [ ! -d $ROOT/opt/htdocs/drupal-6.15/$i ]; then
+	    if [ ! -d $ROOT/opt/htdocs/drupal-6.17/$i ]; then
 		echo "copying $i ..."
-		/bin/cp -a $i $ROOT/opt/htdocs/drupal-6.15/$i
+		/bin/cp -a $i $ROOT/opt/htdocs/drupal-6.17/$i
 	    fi
 	done
 	)
-    /usr/bin/tar cf - -C $ROOT/opt/htdocs/drupal6.bak/ files | /usr/bin/tar xf - -C $ROOT/opt/htdocs/drupal-6.15/
-    /bin/rm -f $ROOT/opt/htdocs/drupal-6.15/install.php
-    /bin/chmod go-w  /opt/htdocs/drupal-6.15/sites/default/
+    /usr/bin/tar cf - -C $ROOT/opt/htdocs/drupal6.bak/ files | /usr/bin/tar xf - -C $ROOT/opt/htdocs/drupal-6.17/
+    /bin/rm -f $ROOT/opt/htdocs/drupal-6.17/install.php
+    /bin/chmod go-w  /opt/htdocs/drupal-6.17/sites/default/
 else
     # newly install
     FQDN=`hostname -f`
@@ -45,29 +45,31 @@ else
 	FQDN=localhost
     fi
     
-    if [ -f $ROOT/opt/htdocs/drupal-6.15/sites/default/settings.php ]; then
-	/bin/mv $ROOT/opt/htdocs/drupal-6.15/sites/default/settings.php \
-	        $ROOT/opt/htdocs/drupal-6.15/sites/default/settings.php.bak
+    if [ -f $ROOT/opt/htdocs/drupal-6.17/sites/default/settings.php ]; then
+	/bin/mv $ROOT/opt/htdocs/drupal-6.17/sites/default/settings.php \
+	        $ROOT/opt/htdocs/drupal-6.17/sites/default/settings.php.bak
     fi
     /usr/bin/sed \
 	-e "s%^\$db_url = 'mysql://username:password@localhost/databasename';%\$db_url = 'pgsql://www@127.0.0.1/drupal6';%" \
 	-e "s%^\$base_url = 'http://localhost';%\$base_url = 'http://$FQDN/drupal6';%" \
-	$ROOT/opt/htdocs/drupal-6.15/sites/default/default.settings.php \
-	> $ROOT/opt/htdocs/drupal-6.15/sites/default/settings.php
+	$ROOT/opt/htdocs/drupal-6.17/sites/default/default.settings.php \
+	> $ROOT/opt/htdocs/drupal-6.17/sites/default/settings.php
 
     /bin/chown www:apache \
-	$ROOT/opt/htdocs/drupal-6.15/sites/default/settings.php 
+	$ROOT/opt/htdocs/drupal-6.17/sites/default/settings.php 
     /bin/chmod 640 \
-	$ROOT/opt/htdocs/drupal-6.15/sites/default/settings.php 
+	$ROOT/opt/htdocs/drupal-6.17/sites/default/settings.php 
     
-    /bin/mkdir -p $ROOT/opt/htdocs/drupal-6.15/files
-    /bin/cp $ROOT/opt/htdocs/drupal-6.15/custom/_htaccess $ROOT/opt/htdocs/drupal-6.15/.htaccess
-    /bin/chown www:apache $ROOT/opt/htdocs/drupal-6.15/files \
-			$ROOT/opt/htdocs/drupal-6.15/.htaccess 
-    /bin/chmod 640 $ROOT/opt/htdocs/drupal-6.15/files \
-			$ROOT/opt/htdocs/drupal-6.15/.htaccess
+    /bin/mkdir -p $ROOT/opt/htdocs/drupal-6.17/files
+    /bin/mkdir -p $ROOT/opt/htdocs/drupal-6.17/sites/default/files
+    /bin/cp $ROOT/opt/htdocs/drupal-6.17/custom/_htaccess $ROOT/opt/htdocs/drupal-6.17/.htaccess
+    /bin/chown www:apache $ROOT/opt/htdocs/drupal-6.17/files \
+			$ROOT/opt/htdocs/drupal-6.17/sites/default/files \
+			$ROOT/opt/htdocs/drupal-6.17/.htaccess 
+    /bin/chmod 640 $ROOT/opt/htdocs/drupal-6.17/files \
+			$ROOT/opt/htdocs/drupal-6.17/.htaccess
 fi
-(cd $ROOT/opt/htdocs; /bin/rm -f drupal6; /bin/ln -sf drupal-6.15 drupal6 )
+(cd $ROOT/opt/htdocs; /bin/rm -f drupal6; /bin/ln -sf drupal-6.17 drupal6 )
 (cd $ROOT/usr/bin; /bin/rm -f drush; /bin/ln -sf ../share/drush/drush drush )
 
 # this script check db existance itself.
@@ -114,7 +116,4 @@ if ! fgrep "drupal6/cron.php" $ROOT/var/spool/cron/crontabs/www 1>/dev/null 2>&1
     echo "0  *  *  *  *	/usr/bin/wget -O - -q http://$FQDN/drupal6/cron.php" >> $ROOT/var/spool/cron/crontabs/www
 fi
 
-#echo "To install japanese package drupal see:"      
-#echo "        http://drupal.jp/drupal6/guide/install-step1" 
-
 #%% end
