@@ -1,33 +1,31 @@
 #!/bin/bash
-# Drupal	(http://drupal.org)(http://drupal.jp)
+# Drupal	(http://drupal.org)
 #	BuildScript for Plamo Linux 4.7
-#			by Jun Kuwamura <juk@linet.gr.jp> on 2009-12-20
+#			by Jun Kuwamura <juk@linet.gr.jp> on 2010-03-11
 # require:
 #	httpd-2.2.x
 #	php-5.2.x
 #	postgresql-8.4.x
 #
+
+
 wget -N http://ftp.drupal.org/files/projects/drush-All-Versions-HEAD.tar.gz
-tar xvfz drush-All-Versions-HEAD.tar.gz 
+tar xfz drush-All-Versions-HEAD.tar.gz 
+
 export PATH=/opt/php5/bin:$PATH
-VERSION=`./drush/drush dl drupal | sed -e s'/.*(\(.*\)).*/\1/'`
-JVERS=`./drush/drush dl ja | sed -e s'/.*(\(.*\)).*/\1/'`
-
-#MVER=14
-#FVER=`printf "%03d" $MVER`
-#VERSION=6.$MVER
-#SRC_URI=http://downloads.sourceforge.net/drupal-jp/${PAC_NAME}-japanese_${FVER}.tgz
-#SRC_FILE=${SRC_URI##*/}
 
+./drush/drush dl drupal > drush-dl-drupal.log
+VERSION=`sed -e s'/.*(\(.*\)).*/\1/' drush-dl-drupal.log`
 PAC_NAME=drupal-$VERSION
+(cd $PAC_NAME; ../drush/drush dl ja > drush-dl-ja.log)
+JVERS=`sed -e s'/.*(\(.*\)).*/\1/' drush-dl-ja.log`
+
 SRC_FILE=${PAC_NAME}-japanese_${JVERS}.tar.gz
+echo $SRC_FILE
 tar cvfz $SRC_FILE $PAC_NAME
 
 JAM_URI=http://downloads.sourceforge.net/drupal-jp/jamail-6.x-1.0.tgz
 JAM_FILE=${JAM_URI##*/}
-# download from http://github.com/juk/drupal-tsearch/tree/37b67213389f4e15efc5648387a175b643bfd5fe
-#TS2_FILE=juk-drupal-tsearch-37b67213389f4e15efc5648387a175b643bfd5fe.tar.gz
-#TS2_DIR=${TS2_FILE%%.tar.gz}
 # using git:# git  clone  git://github.com/juk/drupal-tsearch.git
 
 PLAMO=/expo/Build
@@ -83,8 +81,8 @@ mkdir -p install
 sed -e "s/VERSION/$VERSION/g" \
     -e "s/_PACKAGE_NAME_/${PAC_NAME}-${SYS_NAME}/g" \
   $CUSTOM_DIR/doinst.sh > install/doinst.sh
-echo "To install japanese package drupal see:"
-echo "        http://drupal.jp/drupal6/guide/install-step1"
+#echo "To install japanese package drupal:"
+#echo "        % drush dl ja"
 
 mkdir -p opt/htdocs | exit 1
 cd opt/htdocs
@@ -145,7 +143,7 @@ TYP=2 #(0:httpd, 1:libraries, 2:application)
 cat >> $WORK/opt/htdocs/AppList/${TYP}.${PAC_NAME}.list <<__EOCL__
 TYP	$TYP
 NAM	${PAC_NAME}
-URL	http://drupal.jp/
+URL	http://drupal.org/
 DOC	/${DOC_DIR}/
 EXE	/drupal6/
 REM	content management platform(blog etc.)
